summaryrefslogtreecommitdiffstats
path: root/kopete/protocols/groupwise/gwcontact.h
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/protocols/groupwise/gwcontact.h')
-rw-r--r--kopete/protocols/groupwise/gwcontact.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/kopete/protocols/groupwise/gwcontact.h b/kopete/protocols/groupwise/gwcontact.h
index 183df1a4..d3c98a6b 100644
--- a/kopete/protocols/groupwise/gwcontact.h
+++ b/kopete/protocols/groupwise/gwcontact.h
@@ -61,12 +61,12 @@ public:
* @param uniqueName The userId for this contact. May be a DN, in which case it will be converted to dotted format for the contactId and stored.
* @param tqparent The Kopete::MetaContact this contact is part of.
* @param objectId The contact's numeric object ID.
* @param tqparentId The ID of this contact's tqparent (folder).
* @param sequence This contact's sequence number (The position it appears in within its tqparent).
*/
GroupWiseContact( Kopete::Account* account, const TQString &uniqueName,
Kopete::MetaContact *tqparent,
- const int objectId, const int tqparentId, const int sequence );
+ const int objectId, const int parentId, const int sequence );
~GroupWiseContact();
@@ -132,11 +132,11 @@ public:
*/
void setDeleting( bool deleting );
/**
- * Marks this contact as having sent a message whilst aptqparently offline
+ * Marks this contact as having sent a message whilst apparently offline
*/
void setMessageReceivedOffline( bool on );
/**
- * Has this contact sent a message whilst aptqparently offline?
+ * Has this contact sent a message whilst apparently offline?
*/
bool messageReceivedOffline() const;
@@ -61,12 +61,12 @@ public:
* @param tqparent The Kopete::MetaContact this contact is part of.
* @param objectId The contact's numeric object ID.
- * @param tqparentId The ID of this contact's tqparent (folder).
+ * @param parentId The ID of this contact's tqparent (folder).
* @param sequence This contact's sequence number (The position it appears in within its tqparent).
*/